Pensions Module
===============

The pensions module will provide tools for pension scheme calculations.

.. automodule:: actuneo.pensions
   :members:
   :undoc-members:
   :show-inheritance:

.. note::
   This module is under development. Contributions are welcome!

Planned Features
----------------

* Defined benefit calculations
* Defined contribution projections
* Pension valuation methods
* Contribution schedules
* Regulatory compliance tools

